@@ -20,8 +20,9 @@ from .benchmark import Benchmark
               multiple=True,
               type=click.Choice(['dane', 'dane-no-misc', 'ddt-pos', 'ddt-dep',
                                  'angry-tweets', 'twitter-sent',
-                                 'twitter-subj', 'europarl-subj', 'dkhate',
-                                 'europarl1', 'europarl2', 'lcc1', 'lcc2']),
+                                 'twitter-subj', 'europarl-sent',
+                                 'europarl-subj', 'dkhate', 'lcc', 'norec',
+                                 'nordial']),
               help='The name of the benchmark dataset. If not specified then '
                    'all datasets will be benchmarked.')
 @click.option('--language', '-l',
