@@ -1,18 +1,18 @@
 '''Hate speech classification of a language model on the DKHate dataset'''
 
 from datasets import Dataset
-from typing import Tuple, Dict, Optional
+from typing import Tuple
 import logging
 
-from .text_classification import TextClassificationBenchmark
+from .binary_classification import BinaryClassificationBenchmark
 from .datasets import load_dkhate
-from .utils import doc_inherit, InvalidBenchmark
+from .utils import doc_inherit
 
 
 logger = logging.getLogger(__name__)
 
 
-class DkHateBenchmark(TextClassificationBenchmark):
+class DkHateBenchmark(BinaryClassificationBenchmark):
     '''Benchmark of language models on the DKHate dataset.
 
     Args:
@@ -44,15 +44,8 @@ class DkHateBenchmark(TextClassificationBenchmark):
                  cache_dir: str = '.benchmark_models',
                  evaluate_train: bool = False,
                  verbose: bool = False):
-        id2label = ['NOT', 'OFF']
-        label_synonyms = [
-            ['LABEL_0', 'NOT'],
-            ['LABEL_1', 'OFF']
-        ]
         super().__init__(name='DKHate',
-                         metric_names=dict(f1='F1-score'),
-                         id2label=id2label,
-                         label_synonyms=label_synonyms,
+                         id2label=['NOT', 'OFF'],
                          cache_dir=cache_dir,
                          evaluate_train=evaluate_train,
                          verbose=verbose)
@@ -67,21 +60,3 @@ class DkHateBenchmark(TextClassificationBenchmark):
         train = Dataset.from_dict(train_dict)
         test = Dataset.from_dict(test_dict)
         return train, test
-
-    @doc_inherit
-    def _compute_metrics(self,
-                         predictions_and_labels: tuple,
-                         id2label: Optional[dict] = None) -> Dict[str, float]:
-        predictions, labels = predictions_and_labels
-        predictions = predictions.argmax(axis=-1)
-        results = self._metric.compute(predictions=predictions,
-                                       references=labels)
-        return dict(f1=results['f1'])
-
-    @doc_inherit
-    def _get_spacy_predictions_and_labels(self,
-                                          model,
-                                          dataset: Dataset,
-                                          progress_bar: bool) -> tuple:
-        raise InvalidBenchmark('Evaluation of text classification predictions '
-                               'for SpaCy models is not yet implemented.')
